# RagExperimentDetail

Detailed information about a RAG experiment

## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** | Unique identifier for the experiment | 
**name** | **str** | Name of the experiment | 
**description** | **str** |  | [optional] 
**created_at** | **str** | ISO timestamp when experiment was created | 
**finished_at** | **str** |  | [optional] 
**status** | [**ExperimentStatus**](ExperimentStatus.md) | Current status of the experiment | 
**total_rows** | **int** | Total number of test rows in the experiment | 
**completed_rows** | **int** | Number of test rows completed successfully | 
**failed_rows** | **int** | Number of test rows that failed | 
**total_cost** | **str** |  | [optional] 
**dataset_ref** | [**DatasetRef**](DatasetRef.md) | Reference to the dataset used | 
**eval_list** | [**List[EvalRefOutput]**](EvalRefOutput.md) | List of evaluations being run | 
**dataset_row_filter** | [**List[NewDatasetVersionRowColumnItemRequest]**](NewDatasetVersionRowColumnItemRequest.md) |  | [optional] 
**notebook_id** | **str** |  | [optional] 
**rag_configs** | [**List[RagExperimentDetailRagConfigsInner]**](RagExperimentDetailRagConfigsInner.md) | List of RAG configurations being tested | 
**summary_results** | [**RagSummaryResults**](RagSummaryResults.md) | Summary of results across all test cases | 

## Example

```python
from arthur_observability_sdk._generated.models.rag_experiment_detail import RagExperimentDetail

# TODO update the JSON string below
json = "{}"
# create an instance of RagExperimentDetail from a JSON string
rag_experiment_detail_instance = RagExperimentDetail.from_json(json)
# print the JSON string representation of the object
print(RagExperimentDetail.to_json())

# convert the object into a dict
rag_experiment_detail_dict = rag_experiment_detail_instance.to_dict()
# create an instance of RagExperimentDetail from a dict
rag_experiment_detail_from_dict = RagExperimentDetail.from_dict(rag_experiment_detail_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


